<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://https://codecanyon.net/search/kamleshyadav
 * @since      1.0.0
 *
 * @package    Youtube_Auto_Post
 * @subpackage Youtube_Auto_Post/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Youtube_Auto_Post
 * @subpackage Youtube_Auto_Post/admin
 * @author     kamleshyadav <admin@pixelnx.com>
 */
class Youtube_Auto_Post_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Youtube_Auto_Post_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Youtube_Auto_Post_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/youtube-auto-post-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Youtube_Auto_Post_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Youtube_Auto_Post_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/youtube-auto-post-admin.js', array('jquery'), $this->version, false);
		wp_localize_script($this->plugin_name, 'youtube_auto_post_ajax_path', array(
			'url' => admin_url('admin-ajax.php'),
			'admin_url' => admin_url(),
			) 
	    );

	}
	
	/**
	 * Youtube Auto Post Admin Dashboard Menu Option
	 */
    public function youtube_auto_post_admin_menus(){
    	/**
    	 * Dashboard Menu
    	 */
    	add_menu_page( 
    		esc_html__('Youtube Auto Post','pixelplay'),
    		esc_html__('Youtube Auto Post','pixelplay'),
    		'manage_options',
    		'youtube-auto-post-menu',
    		 array($this, 'youtube_auto_post_menu_pages'),
    		'dashicons-video-alt3',
    		6
      	  );
	}
	/**
	 * Youtube Setting Option Display
	 */ 
	public function youtube_auto_post_menu_pages(){
	    /**
	     * OAUTH Configuration
	     */
	    $oauthClientID = get_option('gl_client_id');
        $oauthClientSecret = get_option('gl_secret_key');
        $baseUri = home_url();
        $redirectUri = home_url('?redirect_url=autopost');
        define('OAUTH_CLIENT_ID',$oauthClientID);
        define('OAUTH_CLIENT_SECRET',$oauthClientSecret);
        define('REDIRECT_URI',$redirectUri);
        define('BASE_URI',$baseUri);
        
        /**
         * Include google client libraries
         */ 
        require_once(YOUTUBE_AUTO_POST_PLUGIN_PATH.'api-library/google/autoload.php');
        require_once(YOUTUBE_AUTO_POST_PLUGIN_PATH.'api-library/google/Client.php');
        require_once(YOUTUBE_AUTO_POST_PLUGIN_PATH.'api-library/google/Service/YouTube.php');
        
        $client = new Google_Client();
        $client->setClientId(OAUTH_CLIENT_ID);
        $client->setClientSecret(OAUTH_CLIENT_SECRET);
        $client->setScopes('https://www.googleapis.com/auth/youtube');
        $client->setRedirectUri(REDIRECT_URI);
        $client->setAccessType('offline');
        
        /**
         * Define an object that will be used to make all API requests.
         */ 
        $youtube = new Google_Service_YouTube($client); 
        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/youtube-auto-post-admin-display.php';
	}
	
	/**
	 * Youtube Api Feed Settings Save
	 */ 
	public function youtube_auto_post_feed_api_settings_save(){
	    $gl_api_key = '';
        if(isset($_POST['gl_api_key'])):
          $gl_api_key = sanitize_text_field($_POST['gl_api_key']);
        endif;
        $gl_youtube_channel_id = '';
        if(isset($_POST['gl_youtube_channel_id'])):
          $gl_youtube_channel_id = sanitize_text_field($_POST['gl_youtube_channel_id']);
        endif;
        update_option('gl_api_key', $gl_api_key);
        update_option('gl_youtube_channel_id', $gl_youtube_channel_id);
        $result_data = array(
                         'status'=> esc_html__('success','youtube-auto-post'),
                         'massage'=> esc_html__('Save Successfully','youtube-auto-post')
                         );
        echo json_encode($result_data);
	    wp_die();  
	}
	/**
	 * Youtube Post Upload Api Settings Save
	 */ 
	public function youtube_auto_post_uplod_api_settings_save(){
	    $gl_client_id = '';
        if(isset($_POST['gl_client_id'])):
          $gl_client_id = sanitize_text_field($_POST['gl_client_id']);
        endif;
        $gl_secret_key = '';
        if(isset($_POST['gl_secret_key'])):
          $gl_secret_key = sanitize_text_field($_POST['gl_secret_key']);
        endif;
        update_option('gl_client_id', $gl_client_id);
        update_option('gl_secret_key', $gl_secret_key);
        $result_data = array(
                        'status'=> esc_html__('success','youtube-auto-post'),
                        'massage'=> esc_html__('Save Successfully','youtube-auto-post')
                        );
        echo json_encode($result_data);
	    wp_die();  
	}
}