<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://https://codecanyon.net/search/kamleshyadav
 * @since      1.0.0
 *
 * @package    Youtube_Auto_Post
 * @subpackage Youtube_Auto_Post/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Youtube_Auto_Post
 * @subpackage Youtube_Auto_Post/public
 * @author     kamleshyadav <admin@pixelnx.com>
 */
class Youtube_Auto_Post_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		
		/**
         * Add Form And Display Data Shortcode 
         */ 
        add_shortcode('youtube_upload_form', array($this,'youtube_auto_post_upload_video_form'));
        add_shortcode('youtube_auto_post_display', array($this,'youtube_auto_post_display'));
        add_shortcode('loginform_display', array($this,'youtube_auto_post_login_shortcode'));

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Youtube_Auto_Post_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Youtube_Auto_Post_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/youtube-auto-post-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Youtube_Auto_Post_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Youtube_Auto_Post_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/youtube-auto-post-public.js', array( 'jquery' ), $this->version, false );
        wp_localize_script($this->plugin_name, 'youtube_auto_post_ajax_path', array(
			'url' => admin_url('admin-ajax.php'),
			'admin_url' => admin_url(),
			) 
	    );

	}
	/**
     * Youtube Auto Post Upload Form Shortcode 
     */ 
    public function youtube_auto_post_upload_video_form(){
        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/youtube-auto-post-public-form-display.php';
    }
    /**
     * Youtube Auto Post Display Shortcode
     */ 
    public function youtube_auto_post_display(){
      require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/youtube-auto-post-public-display.php';
    }
    /**
     * Youtube Video File Upload On Server
     */ 
    public function youtube_auto_post_youtube_video_file(){
        /**
         * OAUTH Configuration
         */ 
        $htmlBody = '';
        $oauthClientID = get_option('gl_client_id');
        $oauthClientSecret = get_option('gl_secret_key');
        $baseUri = home_url();
        $redirectUri = home_url('?redirect_url=autopost'); 
        define('OAUTH_CLIENT_ID',$oauthClientID);
        define('OAUTH_CLIENT_SECRET',$oauthClientSecret);
        define('REDIRECT_URI',$redirectUri);
        define('BASE_URI',$baseUri);
        /**
         * Include google client libraries
         */ 
        require_once(YOUTUBE_AUTO_POST_PLUGIN_PATH.'api-library/google/autoload.php');
        require_once(YOUTUBE_AUTO_POST_PLUGIN_PATH.'api-library/google/Client.php');
        require_once(YOUTUBE_AUTO_POST_PLUGIN_PATH.'api-library/google/Service/YouTube.php');
        
        $client = new Google_Client();
        $client->setClientId(OAUTH_CLIENT_ID);
        $client->setClientSecret(OAUTH_CLIENT_SECRET);
        $client->setScopes('https://www.googleapis.com/auth/youtube');
        $client->setRedirectUri(REDIRECT_URI);
        $client->setAccessType('offline');
        /**
         * Define an object that will be used to make all API requests.
         */ 
        $youtube = new Google_Service_YouTube($client); 
        if(!empty($_FILES["video_file"]["name"])){
            $video_title = '';
            if(isset($_POST['video_title'])):
             $video_title = sanitize_text_field($_POST['video_title']);
            endif; 
            $video_description = '';
            if(isset($_POST['video_description'])):
             $video_description = sanitize_text_field($_POST['video_description']);
            endif;
            $video_tags = '';
            if(isset($_POST['video_tags'])):
             $video_tags = sanitize_text_field($_POST['video_tags']);
            endif;
            $video_privacy = '';
            if(isset($_POST['video_privacy'])):
             $video_privacy = sanitize_text_field($_POST['video_privacy']);
            endif; 
            $upload = wp_upload_bits($_FILES["video_file"]["name"], null, file_get_contents($_FILES["video_file"]["tmp_name"]));
            $upload_image_file = wp_upload_bits($_FILES["video_image_file"]["name"], null, file_get_contents($_FILES["video_image_file"]["tmp_name"]));
            
            $data_collection = json_encode(array(
                                'video_title'=>$video_title,
                                'video_description'=>$video_description,
                                'video_tags'=>$video_tags,
                                'video_privacy'=>$video_privacy,
                                'video_file_data'=> $upload,
                                'upload_image_file'=> $upload_image_file,
                                ));
            $user_id = get_current_user_id();
            $data_save = update_user_meta($user_id,'youtube_upload_data', $data_collection);
            if($data_save > 0){
                /**
                 * Video Save
                 */ 
                $getaccesstoken = get_option('youtube_upload_accesstoken',true);
                if(isset($getaccesstoken)){ 
                  $client->setAccessToken($getaccesstoken); 
                }
                /**
                 * Refresh the token if it's expired.
                 */ 
               if($client->isAccessTokenExpired()) {
    			    $refreshMyToken = $client->refreshToken($client->getRefreshToken());
    			    if (isset($refreshMyToken["error"])) {
    					return false;
    				} else {
    				  $token_data = $client->getAccessToken();
    				  update_option('youtube_upload_accesstoken',$token_data);
    				}
    				
    			}
    			$accesstoken = $client->getAccessToken(); 
                if($accesstoken){
                  try{
                    $video_data = json_decode(get_user_meta($user_id,'youtube_upload_data',true),true);
                    $video_title = '';
                    if(!empty($video_data['video_title'])):
                      $video_title = $video_data['video_title'];
                    endif;
                    $video_description = '';
                    if(!empty($video_data['video_description'])):
                       $video_description = $video_data['video_description'];
                    endif;
                    $video_tags = '';
                    if(!empty($video_data['video_tags'])):
                       $video_tags = $video_data['video_tags'];
                    endif;
                    $video_privacy = '';
                    if(!empty($video_data['video_privacy'])):
                      $video_privacy = $video_data['video_privacy'];
                    endif;
                    $video_base_path_file = '';
                    if(!empty($video_data['video_file_data']['file'])):
                       $video_base_path_file = $video_data['video_file_data']['file'];
                    endif;
                    $video_base_path_url = '';
                    if(!empty($video_data['video_file_data']['url'])):
                      $video_base_path_url = $video_data['video_file_data']['url'];
                    endif;
                    $image_base_path_url = '';
                    if(!empty($video_data['upload_image_file']['url'])):
                      $image_base_path_url = $video_data['upload_image_file']['url'];
                    endif;
                    /**
                     * REPLACE this value with the path to the file you are uploading.
                     */ 
                    $videoPath = $video_base_path_file; 
                    /** Create a snippet with title, description, tags and category ID
                     *  Create an asset resource and set its snippet metadata and type.
                     *  This example sets the video's title, description, keyword tags, and
                     *  video category.
                     */
                    $snippet = new Google_Service_YouTube_VideoSnippet();
                    $snippet->setTitle($video_title);
                    $snippet->setDescription($video_description);
                    $snippet->setTags(explode(",",$video_tags));
                   /**
                     * Numeric video category. See
                     * This is category documention Url :-> https://developers.google.com/youtube/v3/docs/videoCategories/list 
                     */ 
                    $snippet->setCategoryId("22");
                    /**
                     * Set the video's status to "public". Valid statuses are "public",
                     * "private" and "unlisted".
                     */
                    $status = new Google_Service_YouTube_VideoStatus();
                    $status->privacyStatus = $video_privacy;
                    /**
                     * Associate the snippet and status objects with a new video resource.
                     */ 
                    $video = new Google_Service_YouTube_Video();
                    $video->setSnippet($snippet);
                    $video->setStatus($status);
                    /** 
                     * Specify the size of each chunk of data, in bytes. Set a higher value for
                     * reliable connection as fewer chunks lead to faster uploads. Set a lower
                     * value for better recovery on less reliable connections.
                     */
                    $chunkSizeBytes = 1 * 1024 * 1024;
                    /**
                     * Setting the defer flag to true tells the client to return a request which can be called
                     * with ->execute(); instead of making the API call immediately.
                     */
                    $client->setDefer(true);
                    /**
                     * Create a request for the API's videos.insert method to create and upload the video.
                     */ 
                    $insertRequest = $youtube->videos->insert("status,snippet", $video);
                    /**
                     * Create a MediaFileUpload object for resumable uploads.
                     */ 
                    $media = new Google_Http_MediaFileUpload(
                        $client,
                        $insertRequest,
                        'video/*',
                        null,
                        true,
                        $chunkSizeBytes
                    );
                    $media->setFileSize(filesize($videoPath));
                    /**
                     * Priview Image Upload
                     */ 
                    $setRequest = $youtube->thumbnails->set($insertRequest);
                    /**
                     * Create a MediaFileUpload object for resumable uploads.
                     */
                    $media_image = new Google_Http_MediaFileUpload(
                        $client,
                        $setRequest,
                        'image/*',
                        null,
                        true,
                        $chunkSizeBytes
                      );
                    $media_image->setFileSize(filesize($image_base_path_url));
                    /**
                     * Read the media file and upload it.
                     */
                    $status = false;
                    $handle = fopen($videoPath, "rb");
                    while (!$status && !feof($handle)) {
                      $chunk = fread($handle, $chunkSizeBytes);
                      $status = $media->nextChunk($chunk);
                    }
                    fclose($handle);
                    /**
                     * If you want to make other calls after the file upload, set setDefer back to false
                     */ 
                    $client->setDefer(false);
                	/**
                	 * delete video file from local folder
                	 */ 
                	unlink($video_base_path_url);
                	$video_des = $status['snippet']['description'].'<br><embed width="400" height="315" src="'.esc_url("https://www.youtube.com/embed/".$status['id']).'"></embed>';
                    $add_post = array(
                    	'post_title'    => $status['snippet']['title'],
                    	'post_content'  => $video_des,
                    	'post_status'   => 'draft',
                    	'post_author'   => $user_id,
                        );
                    $post_tags = '';
                    if(!empty($status['snippet']['tags'])):
                      $post_tags = explode(",",$status['snippet']['tags']); 
                    endif;
                    $post_id = wp_insert_post($add_post);
                    wp_set_post_tags( $post_id, $post_tags);
                    $response = array(
                         'status'=>'true',
                         'massage'=> esc_html__('Video have been uploaded successfully','youtube-auto-post'),
                         
                        );
                	} catch (Google_ServiceException $e) {
                        $htmlBody .= sprintf('<p>A service error occurred: <code>%s</code></p>',
                        
                        htmlspecialchars($e->getMessage()));
                        $response = array(
                             'status'=>'false',
                             'massage'=> $htmlBody,
                            );
                            
                    } catch (Google_Exception $e) {
                        
                        $htmlBody .= sprintf('<p>An client error occurred: <code>%s</code></p>', htmlspecialchars($e->getMessage()));
                        $response = array(
                             'status'=>'false',
                             'massage'=> $htmlBody,
                            );
                            
                    }
                  
                    
                }else{
                    
                	/**
                	 * If the user hasn't authorized the app, initiate the OAuth flow
                	 */ 
                	$state = mt_rand();
                	$client->setState($state);
                	update_user_meta($user_id,'youtube_upload_state',$state);
                    $authUrl = $client->createAuthUrl();
                	$htmlBody .= '<h3>'.esc_html__('Authorization Required','youtube-auto-post').'</h3>';
                	$htmlBody .= '<p>'.esc_html__('You need to','youtube-auto-post').'<a href="'.esc_url($authUrl).'">'.esc_html__('authorize access','youtube-auto-post').'</a>'.esc_html__('before proceeding.','youtube-auto-post').'<p>';
                    $response = array(
                               'status'=>'false',
                               'massage'=> $htmlBody,
                               );
               } 
                
            }else{
                    $response = array(
                            'status'=>'false',
                            'massage'=> esc_html__('SomeThing Went Wrong!','youtube-auto-post'),
                            );
            }
            echo json_encode($response);
        }
        wp_die(); 
    } 
    
    /**
     * Youtube Auto Post Login ShortCode
     */ 
    public function youtube_auto_post_login_shortcode(){
       require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/youtube-auto-post-login-form-display.php';
    }
    /**
     * Youtube Auto Post Login Form Ajax
     */ 
    public function youtube_auto_post_login_form(){
        check_ajax_referer('ajax-login-nonce', 'security');
        /**
         * Nonce is checked, get the POST data and sign user on
         */ 
        $info = array();
        $info['user_login'] = sanitize_text_field($_POST['username']);
        $info['user_password'] = sanitize_text_field($_POST['password']);
        $info['remember'] = true;
        $user_signon = wp_signon($info, false);
        if(!is_wp_error($user_signon) ){
          wp_set_current_user($user_signon->ID);
          wp_set_auth_cookie($user_signon->ID);
          echo json_encode(array('loggedin'=>true, 
                                 'message'=> esc_html__('Login Successful','youtube-auto-post')));
        }else{
          echo json_encode(array(
                        'loggedin'=>false, 
                        'message'=> esc_html__('Please Check Login Detail','youtube-auto-post'))
                         );   
        }
        wp_die();  
    } 
    
}